@@ -1,8 +1,12 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 OPERATORS = (
+    'where',
+    'not where',
     'child_of',
     'not child_of',
+    'parent_of',
+    'not parent_of',
     '=',
     '!=',
     'like',
@@ -16,3 +20,4 @@ OPERATORS = (
     '<',
     '>',
     )
+MODULES_GROUP = 'trytond.modules'
