@@ -1,8 +1,8 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
+from trytond.pool import Pool
 from trytond.tools.string_ import LazyString
 from trytond.transaction import Transaction
-from trytond.pool import Pool
 
 
 def gettext(message_id, *args, **variables):
@@ -21,10 +21,14 @@ def gettext(message_id, *args, **variables):
     try:
         module, id_ = message_id.split('.')
     except ValueError:
+        if pool.test:
+            raise
         return message_id
     try:
         return Message.gettext(module, id_, language, **variables)
     except (KeyError, ValueError):
+        if pool.test:
+            raise
         return message_id
 
 
