@@ -1,8 +1,8 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 
-from trytond.model import ModelView, ModelSQL, fields
 from trytond.cache import Cache
+from trytond.model import ModelSQL, ModelView, fields
 from trytond.pool import Pool
 from trytond.transaction import Transaction
 
@@ -11,7 +11,7 @@ class Message(ModelSQL, ModelView):
     "Message"
     __name__ = "ir.message"
 
-    _message_cache = Cache('ir.message', size_limit=10240, context=False)
+    _message_cache = Cache('ir.message', context=False)
     text = fields.Text("Text", required=True, translate=True)
 
     @classmethod
