@@ -1,31 +1,31 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 
-from .field import (
-    depends, with_inactive_records, SQL_OPERATORS, on_change_result,
-    get_eval_fields, states_validate, domain_validate, context_validate, Field)
-from .boolean import Boolean
-from .integer import Integer, BigInteger
-from .char import Char
-from .text import Text, FullText
-from .float import Float
-from .numeric import Numeric
-from .date import Date, Timestamp, DateTime, Time, TimeDelta
 from .binary import Binary
-from .selection import Selection
-from .reference import Reference
-from .many2one import Many2One
-from .one2many import One2Many
-from .many2many import Many2Many
-from .function import Function, MultiValue
-from .one2one import One2One
+from .boolean import Boolean
+from .char import Char
+from .date import Date, DateTime, Time, TimeDelta, Timestamp
 from .dict import Dict
+from .field import (
+    SQL_OPERATORS, Field, context_validate, depends, domain_validate,
+    get_eval_fields, on_change_result, states_validate)
+from .float import Float
+from .function import Function, MultiValue
+from .integer import Integer
+from .many2many import Many2Many
+from .many2one import Many2One
 from .multiselection import MultiSelection
+from .numeric import Numeric
+from .one2many import One2Many
+from .one2one import One2One
+from .reference import Reference
+from .selection import Selection
+from .text import FullText, Text
 
 __all__ = [
-    depends, with_inactive_records, SQL_OPERATORS, on_change_result,
+    depends, SQL_OPERATORS, on_change_result,
     get_eval_fields, states_validate, domain_validate, context_validate, Field,
-    Boolean, Integer, BigInteger, Char, Text, FullText, Float, Numeric, Date,
+    Boolean, Integer, Char, Text, FullText, Float, Numeric, Date,
     Timestamp, DateTime, Time, TimeDelta, Binary, Selection, Reference,
     Many2One, One2Many, Many2Many, Function, MultiValue, One2One, Dict,
     MultiSelection]
