@@ -6,8 +6,8 @@ from functools import wraps
 from itertools import chain, groupby, islice, product, repeat
 
 from sql import (
-    Asc, Column, Desc, Expression, For, Literal, Null, NullsFirst, NullsLast,
-    Table, Union, With)
+    Asc, Column, Desc, Expression, Literal, Null, NullsFirst, NullsLast, Table,
+    Union, With)
 from sql.aggregate import Count, Max
 from sql.conditionals import Coalesce
 from sql.functions import CurrentTimestamp, Extract, Substring
@@ -1770,6 +1770,11 @@ class ModelSQL(ModelStorage):
 
         if order is None or order is False:
             order = cls._order
+        if limit is not None or offset:
+            if 'id' not in {oexpr for oexpr, _ in order}:
+                order = order.copy()
+                order.append(('id', None))
+
         tables, expression = cls.__search_query(domain, count, query, order)
 
         main_table, _ = tables[None]
@@ -2135,7 +2140,8 @@ class ModelSQL(ModelStorage):
                 continue
             table = sql.table
             if isinstance(sql, (Unique, Exclude)):
-                lock(connection, cls._table)
+                if backend.name != 'sqlite':
+                    lock(connection, cls._table)
                 columns = list(sql.columns)
                 columns.insert(0, table.id)
                 in_max = transaction.database.IN_MAX // (len(columns) + 1)
@@ -2174,17 +2180,10 @@ class ModelSQL(ModelStorage):
     @dualmethod
     def lock(cls, records=None):
         transaction = Transaction()
-        database = transaction.database
-        connection = transaction.connection
-        table = cls.__table__()
-
-        if records is not None and database.has_select_for():
-            for sub_records in grouped_slice(records):
-                where = reduce_ids(table.id, sub_records)
-                query = table.select(
-                    Literal(1), where=where, for_=For('UPDATE', nowait=True))
-                with connection.cursor() as cursor:
-                    cursor.execute(*query)
+        if records is not None:
+            new_ids = transaction.create_records[cls.__name__]
+            ids = [id_ for id_ in map(int, records) if id_ not in new_ids]
+            transaction.lock_records(cls._table, ids)
         else:
             transaction.lock_table(cls._table)
 
