@@ -11,6 +11,7 @@ import warnings
 from collections import defaultdict
 from decimal import Decimal
 from functools import lru_cache
+from io import StringIO
 from itertools import chain, groupby, islice
 from operator import itemgetter
 
@@ -727,7 +728,7 @@ class ModelStorage(Model):
                     value = getattr(field, descriptor)().__get__(value, eModel)
                 else:
                     value = getattr(value, field_name)
-                if isinstance(value, (list, tuple)):
+                if field._type in {'one2many', 'many2many'}:
                     first = True
                     child_fields_names = [(x[:i + 1] == fields_tree[:i + 1]
                             and x[i + 1:]) or [] for x in fields_names]
@@ -754,6 +755,15 @@ class ModelStorage(Model):
                     value = ''
                 elif isinstance(value, Model):
                     value = str(value)
+                elif isinstance(value, (list, tuple)):
+                    output = StringIO()
+                    writer = csv.writer(
+                        output,
+                        delimiter=',',
+                        quoting=csv.QUOTE_NONE,
+                        escapechar='\\')
+                    writer.writerow(value)
+                    value = output.getvalue().strip()
                 data[fpos] = value
         return [data] + lines
 
@@ -1005,6 +1015,16 @@ class ModelStorage(Model):
                 elif value:
                     return value
 
+            def convert_multiselection(value):
+                if isinstance(value, str) and value:
+                    return next(csv.reader(
+                            value.splitlines(),
+                            delimiter=',',
+                            quoting=csv.QUOTE_NONE,
+                            escapechar='\\'))
+                else:
+                    return value
+
             try:
                 return locals()['convert_%s' % ftype](value)
             except KeyError:
@@ -1113,7 +1133,8 @@ class ModelStorage(Model):
         to_create, to_create_translations = [], []
         to_write, to_write_translations = [], []
         languages = set()
-        while len(data):
+        data = data.copy()
+        while data:
             (row, _, translate) = \
                 process_lines(data, [], fields_def)
             if dispatch(to_create, to_write, row):
@@ -1976,8 +1997,8 @@ class ModelStorage(Model):
                         cls.write(*sum(
                                 (([r], save_values[r]) for r in to_write), ()))
             except Exception:
-                for record in to_create + to_write:
-                    record._values = values[record]
+                for record in chain(to_create, to_write):
+                    record._values = values.get(record)
                 raise
             for record in to_create + to_write:
                 record._init_values = None
