@@ -1,8 +1,10 @@
 # This file is part of Tryton.  The COPYRIGHT file at the toplevel of this
 # repository contains the full copyright notices and license terms.
 from trytond.pool import Pool
-from .model import Model
+
+from .fields import MultiValue
 from .match import MatchMixin
+from .model import Model
 
 
 class MultiValueMixin(object):
@@ -33,13 +35,19 @@ class MultiValueMixin(object):
                 pattern = pattern.copy()
                 pattern[fname] = self
                 break
-        return Value(**pattern)
+        record = Value(**pattern)
+        for oname, ofield in self._fields.items():
+            if (oname != field
+                    and isinstance(ofield, MultiValue)
+                    and self.multivalue_model(oname) == Value):
+                func = getattr(self, 'default_%s' % oname, None)
+                if func:
+                    setattr(record, oname, func(**pattern))
+        return record
 
     def __values(self, field, pattern, match_none=True):
-        Value = self.multivalue_model(field)
-        # Limit the cache to matching records
-        return Value.browse((v for v in self.multivalue_records(field)
-            if v.match(pattern, match_none=match_none)))
+        return [v for v in self.multivalue_records(field)
+            if v.match(pattern, match_none=match_none)]
 
     def get_multivalue(self, name, **pattern):
         Value = self.multivalue_model(name)
