@@ -2,11 +2,11 @@
 # this repository contains the full copyright notices and license terms.
 import logging
 
-from trytond.pool import Pool
-from trytond.config import config
-from trytond.transaction import Transaction
 from trytond import backend
+from trytond.config import config
 from trytond.exceptions import LoginException, RateLimitException
+from trytond.pool import Pool
+from trytond.transaction import Transaction
 
 logger = logging.getLogger(__name__)
 
@@ -25,14 +25,14 @@ def _get_remote_addr(context):
 
 
 def login(dbname, loginname, parameters, cache=True, context=None):
-    DatabaseOperationalError = backend.get('DatabaseOperationalError')
     for count in range(config.getint('database', 'retry'), -1, -1):
         with Transaction().start(dbname, 0, context=context) as transaction:
             pool = _get_pool(dbname)
             User = pool.get('res.user')
             try:
                 user_id = User.get_login(loginname, parameters)
-            except DatabaseOperationalError:
+                break
+            except backend.DatabaseOperationalError:
                 if count:
                     continue
                 raise
@@ -40,7 +40,6 @@ def login(dbname, loginname, parameters, cache=True, context=None):
                 # Let's store any changes done
                 transaction.commit()
                 raise
-        break
     session = None
     if user_id:
         if not cache:
@@ -58,23 +57,26 @@ def login(dbname, loginname, parameters, cache=True, context=None):
 
 
 def logout(dbname, user, session, context=None):
-    DatabaseOperationalError = backend.get('DatabaseOperationalError')
     for count in range(config.getint('database', 'retry'), -1, -1):
         with Transaction().start(dbname, 0, context=context):
             pool = _get_pool(dbname)
             Session = pool.get('ir.session')
             try:
                 name = Session.remove(session)
-            except DatabaseOperationalError:
+                break
+            except backend.DatabaseOperationalError:
                 if count:
                     continue
                 raise
-    logger.info("logout for '%s' from '%s' on database '%s'",
-        name, _get_remote_addr(context), dbname)
+    if name:
+        logger.info("logout for '%s' from '%s' on database '%s'",
+            name, _get_remote_addr(context), dbname)
+    else:
+        logger.error("logout failed for '%s' from '%s' on database '%s'",
+            user, _get_remote_addr(context), dbname)
 
 
 def check(dbname, user, session, context=None):
-    DatabaseOperationalError = backend.get('DatabaseOperationalError')
     for count in range(config.getint('database', 'retry'), -1, -1):
         with Transaction().start(dbname, user, context=context) as transaction:
             pool = _get_pool(dbname)
@@ -82,7 +84,7 @@ def check(dbname, user, session, context=None):
             try:
                 find = Session.check(user, session)
                 break
-            except DatabaseOperationalError:
+            except backend.DatabaseOperationalError:
                 if count:
                     continue
                 raise
@@ -103,7 +105,6 @@ def check(dbname, user, session, context=None):
 
 
 def check_timeout(dbname, user, session, context=None):
-    DatabaseOperationalError = backend.get('DatabaseOperationalError')
     for count in range(config.getint('database', 'retry'), -1, -1):
         with Transaction().start(dbname, user, context=context) as transaction:
             pool = _get_pool(dbname)
@@ -111,7 +112,7 @@ def check_timeout(dbname, user, session, context=None):
             try:
                 valid = Session.check_timeout(user, session)
                 break
-            except DatabaseOperationalError:
+            except backend.DatabaseOperationalError:
                 if count:
                     continue
                 raise
@@ -124,11 +125,10 @@ def check_timeout(dbname, user, session, context=None):
 
 
 def reset(dbname, session, context):
-    DatabaseOperationalError = backend.get('DatabaseOperationalError')
     try:
-        with Transaction().start(dbname, 0, context=context):
+        with Transaction().start(dbname, 0, context=context, autocommit=True):
             pool = _get_pool(dbname)
             Session = pool.get('ir.session')
             Session.reset(session)
-    except DatabaseOperationalError:
+    except backend.DatabaseOperationalError:
         logger.debug('Reset session failed', exc_info=True)
